Board: TiledBoard
*****************

**TiledBoard** is a child class of **Board**


.. mermaid::

   classDiagram
      Board <|-- PixelBoard
      Board <|-- TiledBoard
      class Board{
      }
      class PixelBoard{

      }
      class TiledBoard{
      }  


TiledBoard
==========


.. autoclass:: miniworldmaker.boards.tiled_board.TiledBoard
   :members:


